@@ -1,6 +1,6 @@
 #!/usr/bin/python
 import sys
-from tspf.main import main
+from src.tspf.main import main
 
 if __name__ == '__main__':
     main(sys.argv)
\ No newline at end of file
